val publishGroupId: String by rootProject.extra
val publishVersion: String by rootProject.extra
val publishArtifactId = "simpleinstaller"

plugins {
	id("com.android.library")
	kotlin("android")
	`maven-publish`
	signing
}

android {
	compileSdk = 33
	buildToolsVersion = "33.0.0"
	namespace = "$publishGroupId.$publishArtifactId"

	defaultConfig {
		minSdk = 16
		targetSdk = 33
		version = publishVersion
		consumerProguardFiles("consumer-rules.pro")
	}

	publishing {
		singleVariant("release") {
			withSourcesJar()
		}
	}

	buildTypes {
		release {
			isMinifyEnabled = false
			proguardFiles(getDefaultProguardFile("proguard-android-optimize.txt"), "proguard-rules.pro")
		}
	}

	compileOptions {
		sourceCompatibility = JavaVersion.VERSION_1_8
		targetCompatibility = JavaVersion.VERSION_1_8
	}

	kotlinOptions {
		jvmTarget = "1.8"
		freeCompilerArgs += listOf("-Xexplicit-api=strict", "-Xjvm-default=all-compatibility")
	}
}

dependencies {
	api("org.jetbrains.kotlinx:kotlinx-coroutines-android:1.6.4")
	api("androidx.startup:startup-runtime:1.1.1")
	implementation("androidx.appcompat:appcompat:1.5.1")
	implementation("androidx.lifecycle:lifecycle-runtime-ktx:2.5.1")
	implementation("com.squareup.okio:okio:3.2.0")
}

afterEvaluate {
	publishing {
		publications {
			create<MavenPublication>("release") {
				groupId = publishGroupId
				artifactId = publishArtifactId
				version = publishVersion
				from(components.getByName("release"))

				pom {
					name.set(publishArtifactId)
					description.set("Easy to use Android package installer wrapper leveraging Kotlin coroutines (API 16+)")
					url.set("https://github.com/solrudev/SimpleInstaller")

					licenses {
						license {
							name.set("The Apache Software License, Version 2.0")
							url.set("https://www.apache.org/licenses/LICENSE-2.0.txt")
						}
					}

					developers {
						developer {
							id.set("solrudev")
							name.set("Ilya Fomichev")
						}
					}

					scm {
						connection.set("scm:git:github.com/solrudev/SimpleInstaller.git")
						developerConnection.set("scm:git:ssh://github.com/solrudev/SimpleInstaller.git")
						url.set("https://github.com/solrudev/SimpleInstaller/tree/master")
					}
				}
			}
		}
	}
}

signing {
	val keyId = rootProject.extra["signing.keyId"] as String
	val key = rootProject.extra["signing.key"] as String
	val password = rootProject.extra["signing.password"] as String
	useInMemoryPgpKeys(keyId, key, password)
	sign(publishing.publications)
}